@@ -26,6 +26,8 @@
   ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+  Author: Naga Samrat Chowdary Narla,
 \*****************************************************************************/
 
 #include "HPCupsFilter.h"
@@ -293,8 +295,6 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
     m_JA.color_mode = cups_header->cupsRowStep;
     m_JA.media_source = cups_header->MediaPosition;
 
-    m_JA.color_mode = cups_header->cupsRowStep;
-    m_JA.media_source = cups_header->MediaPosition;
     m_JA.print_borderless = (cups_header->ImagingBoundingBox[0] == 0) ? true : false;
     if (cups_header->Duplex) {
         m_JA.e_duplex_mode  = (cups_header->Tumble == 0) ? DUPLEXMODE_BOOK : DUPLEXMODE_TABLET;
@@ -352,6 +352,11 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
         if (m_iLogLevel & BASIC_LOG) {
             dbglog("HPCUPS: found Printer Platform, it is - %s", attr->value);
         }
+      if(strcmp(m_JA.printer_platform, "ljzjscolor") == 0)
+      {
+        if(((attr = ppdFindAttr(m_ppd, "hpLJZjsColorVersion", NULL)) != NULL) && (attr->value != NULL))
+          m_JA.printer_platform_version = atoi(attr->value);
+      }
     }
 
 // Get the encapsulation technology from ppd
@@ -421,6 +426,7 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
     }
 
     m_pPrinterBuffer = new BYTE[cups_header->cupsWidth * 4 + 32];
+    
 
     return NO_ERROR;
 }
@@ -531,14 +537,24 @@ int HPCupsFilter::StartPrintJob(int  argc, char *argv[])
     return 0;
 }
 
-bool HPCupsFilter::isBlankRaster(BYTE *input_raster, int length_in_bytes)
-{
+bool HPCupsFilter::isBlankRaster(BYTE *input_raster, cups_page_header2_t *header)
+{   
+    int length_in_bytes = (int)header->cupsBytesPerLine;
     if (input_raster == NULL) {
         return true;
     }
-    if (*input_raster == 0xFF &&
-        !(memcmp(input_raster + 1, input_raster, length_in_bytes - 1))) {
-    return true;
+
+    if(header->cupsColorSpace == CUPS_CSPACE_K){
+	if (*input_raster == 0x00 &&
+            !(memcmp(input_raster + 1, input_raster, length_in_bytes - 1))) {
+        return true;
+        }
+    }
+    else{
+        if (*input_raster == 0xFF &&
+              !(memcmp(input_raster + 1, input_raster, length_in_bytes - 1))) {
+        return true;
+        }
     }
     return false;
 }
@@ -554,6 +570,7 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
     DRIVER_ERROR           err;
     int                    ret_status = 0;
 
+       
     while (cupsRasterReadHeader2(cups_raster, &cups_header))
     {
         current_page_number++;
@@ -582,6 +599,7 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
             rgbRaster = NULL;
         }
         else if (cups_header.cupsColorSpace != CUPS_CSPACE_RGBW) {
+            dbglog("5......\n");
             rgbRaster = m_pPrinterBuffer;
             kRaster = NULL;
         }
@@ -597,7 +615,7 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
             ret_status = JOB_CANCELED;
             break;
         }
-
+        
         if (m_iLogLevel & SAVE_INPUT_RASTERS)
         {
             char    szFileName[32];
@@ -616,8 +634,10 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
                 kfp = fopen (szFileName, "w");
                 chmod (szFileName, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
             }
+            dbglog("9......\n");
             WriteBMPHeader (cfp, cups_header.cupsWidth, cups_header.cupsHeight, COLOR_RASTER);
             WriteBMPHeader (kfp, cups_header.cupsWidth, cups_header.cupsHeight, BLACK_RASTER);
+            dbglog("10......\n");
         }
 
         fprintf(stderr, "PAGE: %d %s", current_page_number, m_argv[4]);
@@ -627,7 +647,8 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
             color_raster = rgbRaster;
             black_raster = kRaster;
 
-            if (this->isBlankRaster((BYTE *) m_pPrinterBuffer, (int) cups_header.cupsBytesPerLine)) {
+            if (this->isBlankRaster((BYTE *) m_pPrinterBuffer, &cups_header)) {
+            
                 color_raster = NULL;
                 black_raster = NULL;
             }
@@ -688,10 +709,18 @@ static BYTE pixel_value[8] = {
             if (b != 0 && b != 0xFF) {
 
 #ifdef __linux
-                rgb[0] -= (255 - b);
-                rgb[1] -= (255 - b);
-                rgb[2] -= (255 - b);
-                
+              //  rgb[0] -= (255 - b);
+              //  rgb[1] -= (255 - b);
+              //  rgb[2] -= (255 - b);
+              int cr,cg,cb;
+              cr = rgb[0] - (int)(255 - b);
+              rgb[0] = cr >= 0 ? cr : 0;
+
+              cg = rgb[1] - (int)(255 - b);
+              rgb[1] = cg >= 0 ? cg : 0;
+
+              cb = rgb[2] - (int)(255 - b);
+              rgb[2] = cb >= 0 ? cb : 0;  
 #else  // This alternate path is for Mac....
 
                 rgb[0] &= b;
@@ -701,6 +730,8 @@ static BYTE pixel_value[8] = {
             }
             else
                 kVal |= (b == 0) ? pixel_value[k] : 0;
+           // else if (rgb[0] == rgb[1] && rgb[1] ==rgb[2])
+              //  kVal |= (rgb[0] == 0) ? pixel_value[k] : 0;
             rgb += 3;
             if (k == 7) {
                 *black++ = kVal;
